# MLTU - Machine Learning Training Utilities (TensorFlow)
Machine Learning Training Utilities with TensorFlow 2.* and Python 3

# Installation:
To use MLTU in your own project, you can install it from PyPI:
```bash
pip install mltu
```
When running tutorials, it's necessary to install mltu for a specific tutorial, for example:
```bash
pip install mltu==0.1.3
```
Each tutorial has its own requirements.txt file for a specific mltu version. As this project progress, the newest versions may have breaking changes, so it's recommended to use the same version as in the tutorial.

# Tutorials and Examples:
1. [Text Recognition With TensorFlow and CTC network](https://pylessons.com/ctc-text-recognition), code in ```Tutorials\01_image_to_word``` folder;
2. [TensorFlow OCR model for reading Captchas](https://pylessons.com/tensorflow-ocr-captcha), code in ```Tutorials\02_captcha_to_text``` folder;